==> tecfy_corev2_package-1.0.1.tar.gz: lib/models/user.model.dart <==
part of tecfy_corev2_client_package;

class User {
  String? id;
  String? companyId;
  String? username;
  late String fullName;
  late String? email;
  String? mobile;
  String? identityNo;
  String? code;
  String? display;
  String? photoUrl;
  int? recordNumber;
  bool isSuperuser = false;
  bool canSellWithoutInventory = false;
  bool canAccessPOS = false;
  bool canSellCredit = false;
  bool canViewPosRegisterValues = false;
  num maxDiscountPercentageSalesInvoice = 0;
  List<String> stores = [];
  List<String> paymentMethods = [];
  User(
      {required this.id,
      required this.recordNumber,
      this.username,
      this.mobile,
      this.email,
      required this.fullName,
      this.photoUrl,
      this.display,
      this.code,
      this.identityNo,
      this.canSellCredit = false,
      this.canViewPosRegisterValues = false,
      this.maxDiscountPercentageSalesInvoice = 0,
      this.isSuperuser = false,
      this.canSellWithoutInventory = false,
      this.canAccessPOS = true});

  User.fromJson(Map<String, dynamic>? map) {
    if (map == null) {
      id = null;
      return;
    }
    id = map['_id'].toString();
    recordNumber = map['recordNumber'];
    username = map['username'] ?? '';
    companyId = map['companyId'];
    fullName = map['fullName'] ?? '';
    email = map['email'] ?? '';
    mobile = map['mobile'] ?? '';
    identityNo = map['identityNo'] ?? '';
    code = map['code'] ?? '';
    display = map['display'] ?? '';
    isSuperuser = BaseModel.getBoolEx(map['isSuperuser']);
    canSellWithoutInventory =
        BaseModel.getBoolEx(map['canSellWithoutInventory']);
    canAccessPOS = BaseModel.getBoolEx(map['canAccessPOS']);
    canSellCredit = BaseModel.getBoolEx(map['canSellCredit']);
    canViewPosRegisterValues =
        BaseModel.getBoolEx(map['canViewPosRegisterValues']);
    maxDiscountPercentageSalesInvoice =
        map['maxDiscountPercentageSalesInvoice'] ?? 0;
    if (map['stores'] != null)
      stores = map['stores'].map<String>((e) => e.toString()).toList();
    if (map['paymentMethods'] != null)
      paymentMethods =
          map['paymentMethods'].map<String>((e) => e.toString()).toList();
  }

  toJson() {
    return {
      'id': id,
      'recordNumber': recordNumber,
      'username': username,
      'companyId': companyId,
      'fullName': fullName,
      'code': code,
      'mobile': mobile,
      'identityNo': identityNo,
      'email': email,
      'display': display,
      'isSuperuser': isSuperuser,
      'canSellWithoutInventory': canSellWithoutInventory,
      'canAccessPOS': canAccessPOS,
      'canSellCredit': canSellCredit,
      'canViewPosRegisterValues': canViewPosRegisterValues,
      'maxDiscountPercentageSalesInvoice': maxDiscountPercentageSalesInvoice,
      'stores': stores,
      'paymentMethods': paymentMethods
    };
  }
}

==> tecfy_corev2_package-1.1.30.tar.gz: lib/models/user.model.dart <==
part of tecfy_corev2_client_package;

class User {
  String? id;
  // String? companyId;
  String? nameAr;
  String? nameEn;
  String get fullName => nameAr ?? '';
  late String? email;
  String? mobile;
  String? identityNo;
  String? code;
  String? display;
  String? photoUrl;
  int? recordNumber;
  bool isSuperuser = false;
  bool canSellWithoutInventory = false;
  bool canAccessPOS = false;
  bool canSellCredit = false;
  bool canViewPosRegisterValues = false;
  num maxDiscountPercentageSalesInvoice = 0;
  List<String> stores = [];
  List<String> paymentMethods = [];
  User(
      {required this.id,
      required this.recordNumber,
      // this.username,
      this.mobile,
      this.email,
      // required this.fullName,
      this.photoUrl,
      this.display,
      this.code,
      this.identityNo,
      this.canSellCredit = false,
      this.canViewPosRegisterValues = false,
      this.maxDiscountPercentageSalesInvoice = 0,
      this.isSuperuser = false,
      this.canSellWithoutInventory = false,
      this.canAccessPOS = true});

  User.fromJson(Map<String, dynamic>? map) {
    if (map == null) {
      id = null;
      return;
    }
    id = map['_id'].toString();
    recordNumber = map['recordNumber'];
    nameAr = map['name']?['ar'] ?? '';
    nameEn = map['name']?['en'] ?? '';
    // companyId = map['companyId'];
    // fullName = map['fullName'] ?? '';
    email = map['email'] ?? '';
    mobile = map['mobile'] ?? '';
    identityNo = map['identityNo'] ?? '';
    code = map['code'] ?? '';
    display = map['display'] ?? '';
    isSuperuser = BaseModel.getBoolEx(map['isSuperuser']);
    canSellWithoutInventory =
        BaseModel.getBoolEx(map['canSellWithoutInventory']);
    canAccessPOS = BaseModel.getBoolEx(map['canAccessPOS']);
    canSellCredit = BaseModel.getBoolEx(map['canSellCredit']);
    canViewPosRegisterValues =
        BaseModel.getBoolEx(map['canViewPosRegisterValues']);
    maxDiscountPercentageSalesInvoice =
        map['maxDiscountPercentageSalesInvoice'] ?? 0;
    if (map['stores'] != null)
      stores = map['stores'].map<String>((e) => e.toString()).toList();
    if (map['paymentMethods'] != null)
      paymentMethods =
          map['paymentMethods'].map<String>((e) => e.toString()).toList();
  }

  toJson() {
    return {
      'id': id,
      'recordNumber': recordNumber,
      'name': {
        'ar': nameAr,
        'en': nameEn,
      },
      // 'username': username,
      // 'companyId': companyId,
      'fullName': fullName,
      'code': code,
      'mobile': mobile,
      'identityNo': identityNo,
      'email': email,
      'display': display,
      'isSuperuser': isSuperuser,
      'canSellWithoutInventory': canSellWithoutInventory,
      'canAccessPOS': canAccessPOS,
      'canSellCredit': canSellCredit,
      'canViewPosRegisterValues': canViewPosRegisterValues,
      'maxDiscountPercentageSalesInvoice': maxDiscountPercentageSalesInvoice,
      'stores': stores,
      'paymentMethods': paymentMethods
    };
  }
}
